==> release.12.0.73.1.tgz: prontus/cpan/js-local/CombosTax.class.js <==
var CombosTax = {
    taxonomia: null,
    objFormFid: '', // se setea en el doc. ready
    tag_seccion: '_SECCION',
    tag_nom_seccion: '_NOM_SECCION',
    tag_tema: '_TEMA',
    tag_nom_tema: '_NOM_TEMA',
    tag_subtema: '_SUBTEMA',
    tag_nom_subtema: '_NOM_SUBTEMA',

    // ---------------------------------------------
    init: function() {
        CombosTax.loadTax();
        for(var i = 1; i < 4; i++) {
            $("select[name='" + CombosTax.tag_seccion + i + "']").on('change', function () {
                var name = $(this)[0].name;
                var id = name.substring(name.length -1);
                CombosTax.generaTemas(id);
            });
            $("select[name='" + CombosTax.tag_tema + i + "']").on('change', function () {
                var name = $(this)[0].name;
                var id = name.substring(name.length -1);
                CombosTax.generaSubtemas(id);
            });
        }
    },

    generaTemas: function(num, tema_selected) {
        var theForm = CombosTax.objFormFid;
        if ((typeof(theForm[CombosTax.tag_seccion + num]) == 'undefined') || (typeof(theForm[CombosTax.tag_tema + num]) == 'undefined')) {
            return false;
        }

        var secciones = theForm[CombosTax.tag_seccion + num];
        var id_seccion = secciones.options[secciones.selectedIndex].value;
        if (id_seccion < 0) {
            return false;
        }

        var combo_temas = theForm[CombosTax.tag_tema + num];
        // borra combo temas
        for(let i = 0; i < combo_temas.options.length; i++) {
            combo_temas.options[i] = null;
        }
        combo_temas.options.length = 0;

        if (typeof(CombosTax.taxonomia[id_seccion]) !== 'undefined') {
            let i = 1;
            var temas = CombosTax.taxonomia[id_seccion]['temas'];
            for (var id_tema in temas) {
                combo_temas.options[i] = new Option(temas[id_tema]['nombre'], id_tema);
                if (id_tema == tema_selected) {
                    combo_temas.options[i].selected = true;
                }
                i++;
            }
            if (i > 1) {
                combo_temas.options[0] = new Option('Selecciona Tema', '0');
                if (typeof(tema_selected) === 'undefined' || tema_selected == 0) {
                    combo_temas.options[0].selected = true;
                }
            }
        }
        var combo_subtemas = theForm[CombosTax.tag_subtema + num];
        combo_subtemas.options.length = 0;

        return true;
    },

    // ---------------------------------------------
    generaSubtemas: function(num, subtema_selected) {
        var theForm = CombosTax.objFormFid;
        if ((typeof(theForm[CombosTax.tag_tema + num]) == 'undefined') || (typeof(theForm[CombosTax.tag_subtema + num]) == 'undefined')) {
            return false;
        }
        var secciones = theForm[CombosTax.tag_seccion + num];
        var id_seccion = secciones.options[secciones.selectedIndex].value;
        if (id_seccion < 0) {
            return false;
        }
        var temas = theForm[CombosTax.tag_tema + num];
        if (temas.selectedIndex < 0) {
            return false;
        }
        var id_temas = temas.options[temas.selectedIndex].value;
        if (id_temas < 0) {
            return false;
        }

        var combo_subtemas = theForm[CombosTax.tag_subtema + num];
        var i;
        // borra combo subtemas
        for(i = 0; i < combo_subtemas.options.length; i++) {
            combo_subtemas.options[i] = null;
        }
        combo_subtemas.options.length = 0;

        if (typeof(CombosTax.taxonomia[id_seccion]['temas'][id_temas]) !== 'undefined') {
            i = 1;
            var subtemas = CombosTax.taxonomia[id_seccion]['temas'][id_temas]['subtemas'];
            for (var id_subtema in subtemas) {
                combo_subtemas.options[i] = new Option(subtemas[id_subtema]['nombre'], id_subtema);
                if (id_subtema == subtema_selected) {
                    combo_subtemas.options[i].selected = true;
                }
                i++;
            }
            if (i > 1) {
                combo_subtemas.options[0] = new Option('Selecciona Subtema', '0');
                if (typeof(subtema_selected) === 'undefined' || subtema_selected == 0) {
                    combo_subtemas.options[0].selected = true;
                }
            }
        }

        return true;
    },

    // ---------------------------------------------
    fillSeccTemStem: function() {
        var theForm = CombosTax.objFormFid;
        var cmb, nom;
        // TRIPLETAS
        for (var i = 1; i < 4; i++) {
            if (typeof(theForm[CombosTax.tag_seccion +i]) !== 'undefined') {
                cmb = theForm[CombosTax.tag_seccion+i];
                nom = theForm[CombosTax.tag_nom_seccion+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

                cmb = theForm[CombosTax.tag_tema+i];
                nom = theForm[CombosTax.tag_nom_tema+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

                cmb = theForm[CombosTax.tag_subtema+i];
                nom = theForm[CombosTax.tag_nom_subtema+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

            }
        }
    },

    loadTax: function() {
        var dataURL = '/' + Admin.prontus_id + '/cpan/procs/data4fids/taxs.json';
        $.ajax({
            type: "GET",
            dataType: 'json',
            url: dataURL,
            cache: false,
            success: function (data) {
                CombosTax.taxonomia = data;
                for (var i = 0; i < 3; i++) {
                    var tema_selected = '';
                    var subtema_selected = '';
                    if (typeof mainFidJs !== 'undefined' &&
                        typeof CombosTax.objFormFid[CombosTax.tag_seccion+(i+1)] !== 'undefined') {
                        tema_selected = mainFidJs.ID_TEMA_SELECTED[i];
                        subtema_selected = mainFidJs.ID_SUBTEMA_SELECTED[i];

                        // Completar datos si la taxonomia esta en uso pero ya no está activa
                        let id_seccion = CombosTax.objFormFid[CombosTax.tag_seccion+(i+1)].value;
                        if (id_seccion > 0 && !CombosTax.taxonomia[id_seccion]) {
                            CombosTax.taxonomia[id_seccion] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'] = new Object();
                            CombosTax.taxonomia[id_seccion]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_seccion+(i+1)].value;
                        }
                        if (tema_selected > 0 && !CombosTax.taxonomia[id_seccion]['temas'][tema_selected]) {
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_tema+(i+1)].value;
                        }
                        if (subtema_selected > 0 && !CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected]) {
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_subtema+(i+1)].value;
                        }
                    }
                    CombosTax.generaTemas((i+1), tema_selected);
                    CombosTax.generaSubtemas((i+1), subtema_selected);
                }
            },
            error: function(XMLHttpRequest, textStatus, errorThrown) {
                console.log("no se pudo cargar taxonomia", textStatus, errorThrown, XMLHttpRequest);
            }
        });
    }
};

==> release.12.2.28.1.tgz: prontus/cpan/js-local/CombosTax.class.js <==
var CombosTax = {
    taxonomia: null,
    objFormFid: '', // se setea en el doc. ready
    tag_seccion: '_seccion',
    tag_nom_seccion: '_nom_seccion',
    tag_tema: '_tema',
    tag_nom_tema: '_nom_tema',
    tag_subtema: '_subtema',
    tag_nom_subtema: '_nom_subtema',

    // ---------------------------------------------
    init: function() {
        CombosTax.loadTax();
        for(var i = 1; i < 4; i++) {
            $("select[name='" + CombosTax.tag_seccion + i + "']").on('change', function () {
                var name = $(this)[0].name;
                var id = name.substring(name.length -1);
                CombosTax.generaTemas(id);
            });
            $("select[name='" + CombosTax.tag_tema + i + "']").on('change', function () {
                var name = $(this)[0].name;
                var id = name.substring(name.length -1);
                CombosTax.generaSubtemas(id);
            });
        }
    },

    generaTemas: function(num, tema_selected) {
        var theForm = CombosTax.objFormFid;
        if ((typeof(theForm[CombosTax.tag_seccion + num]) == 'undefined') || (typeof(theForm[CombosTax.tag_tema + num]) == 'undefined')) {
            return false;
        }

        var secciones = theForm[CombosTax.tag_seccion + num];
        var id_seccion = secciones.options[secciones.selectedIndex].value;
        if (id_seccion < 0) {
            return false;
        }

        var combo_temas = theForm[CombosTax.tag_tema + num];
        // borra combo temas
        for(let i = 0; i < combo_temas.options.length; i++) {
            combo_temas.options[i] = null;
        }
        combo_temas.options.length = 0;

        if (typeof(CombosTax.taxonomia[id_seccion]) !== 'undefined') {
            let i = 1;
            var temas = CombosTax.taxonomia[id_seccion]['temas'];
            for (var id_tema in temas) {
                combo_temas.options[i] = new Option(temas[id_tema]['nombre'], id_tema);
                if (id_tema == tema_selected) {
                    combo_temas.options[i].selected = true;
                }
                i++;
            }
            if (i > 1) {
                combo_temas.options[0] = new Option('Selecciona Tema', '0');
                if (typeof(tema_selected) === 'undefined' || tema_selected == 0) {
                    combo_temas.options[0].selected = true;
                }
            }
        }
        var combo_subtemas = theForm[CombosTax.tag_subtema + num];
        combo_subtemas.options.length = 0;

        return true;
    },

    // ---------------------------------------------
    generaSubtemas: function(num, subtema_selected) {
        var theForm = CombosTax.objFormFid;
        if ((typeof(theForm[CombosTax.tag_tema + num]) == 'undefined') || (typeof(theForm[CombosTax.tag_subtema + num]) == 'undefined')) {
            return false;
        }
        var secciones = theForm[CombosTax.tag_seccion + num];
        var id_seccion = secciones.options[secciones.selectedIndex].value;
        if (id_seccion < 0) {
            return false;
        }
        var temas = theForm[CombosTax.tag_tema + num];
        if (temas.selectedIndex < 0) {
            return false;
        }
        var id_temas = temas.options[temas.selectedIndex].value;
        if (id_temas < 0) {
            return false;
        }

        var combo_subtemas = theForm[CombosTax.tag_subtema + num];
        var i;
        // borra combo subtemas
        for(i = 0; i < combo_subtemas.options.length; i++) {
            combo_subtemas.options[i] = null;
        }
        combo_subtemas.options.length = 0;

        if (typeof(CombosTax.taxonomia[id_seccion]['temas'][id_temas]) !== 'undefined') {
            i = 1;
            var subtemas = CombosTax.taxonomia[id_seccion]['temas'][id_temas]['subtemas'];
            for (var id_subtema in subtemas) {
                combo_subtemas.options[i] = new Option(subtemas[id_subtema]['nombre'], id_subtema);
                if (id_subtema == subtema_selected) {
                    combo_subtemas.options[i].selected = true;
                }
                i++;
            }
            if (i > 1) {
                combo_subtemas.options[0] = new Option('Selecciona Subtema', '0');
                if (typeof(subtema_selected) === 'undefined' || subtema_selected == 0) {
                    combo_subtemas.options[0].selected = true;
                }
            }
        }

        return true;
    },

    // ---------------------------------------------
    fillSeccTemStem: function() {
        var theForm = CombosTax.objFormFid;
        var cmb, nom;
        // TRIPLETAS
        for (var i = 1; i < 4; i++) {
            if (typeof(theForm[CombosTax.tag_seccion +i]) !== 'undefined') {
                cmb = theForm[CombosTax.tag_seccion+i];
                nom = theForm[CombosTax.tag_nom_seccion+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

                cmb = theForm[CombosTax.tag_tema+i];
                nom = theForm[CombosTax.tag_nom_tema+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

                cmb = theForm[CombosTax.tag_subtema+i];
                nom = theForm[CombosTax.tag_nom_subtema+i];
                if (cmb.selectedIndex >= 0) {
                    nom.value = (cmb.options[cmb.selectedIndex].value <= 0) ? '' : cmb.options[cmb.selectedIndex].text;
                } else {
                    nom.value = '';
                }

            }
        }
    },

    loadTax: function() {
        var dataURL = '/' + Admin.prontus_id + '/cpan/procs/data4fids/taxs.json';
        $.ajax({
            type: "GET",
            dataType: 'json',
            url: dataURL,
            cache: false,
            success: function (data) {
                CombosTax.taxonomia = data;
                for (var i = 0; i < 3; i++) {
                    var tema_selected = '';
                    var subtema_selected = '';
                    if (typeof mainFidJs !== 'undefined' &&
                        typeof CombosTax.objFormFid[CombosTax.tag_seccion+(i+1)] !== 'undefined') {
                        tema_selected = mainFidJs.ID_TEMA_SELECTED[i];
                        subtema_selected = mainFidJs.ID_SUBTEMA_SELECTED[i];

                        // Completar datos si la taxonomia esta en uso pero ya no está activa
                        let id_seccion = CombosTax.objFormFid[CombosTax.tag_seccion+(i+1)].value;
                        if (id_seccion > 0 && !CombosTax.taxonomia[id_seccion]) {
                            CombosTax.taxonomia[id_seccion] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'] = new Object();
                            CombosTax.taxonomia[id_seccion]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_seccion+(i+1)].value;
                        }
                        if (tema_selected > 0 && !CombosTax.taxonomia[id_seccion]['temas'][tema_selected]) {
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_tema+(i+1)].value;
                        }
                        if (subtema_selected > 0 && !CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected]) {
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected] = new Object();
                            CombosTax.taxonomia[id_seccion]['temas'][tema_selected]['subtemas'][subtema_selected]['nombre'] = CombosTax.objFormFid[CombosTax.tag_nom_subtema+(i+1)].value;
                        }
                    }
                    CombosTax.generaTemas((i+1), tema_selected);
                    CombosTax.generaSubtemas((i+1), subtema_selected);
                }
            },
            error: function(XMLHttpRequest, textStatus, errorThrown) {
                console.log("no se pudo cargar taxonomia", textStatus, errorThrown, XMLHttpRequest);
            }
        });
    }
};
